==> ux-reward-wrap-2.0.13.tgz: package/lib/components/pageBuilder/ElementCollection/RewardWrap/index.js <==
import "core-js/modules/es6.object.assign";
import _classCallCheck from "@babel/runtime/helpers/classCallCheck";
import _createClass from "@babel/runtime/helpers/createClass";
import _possibleConstructorReturn from "@babel/runtime/helpers/possibleConstructorReturn";
import _getPrototypeOf from "@babel/runtime/helpers/getPrototypeOf";
import _inherits from "@babel/runtime/helpers/inherits";
import * as React from 'react';
import Reward from './Reward'; //打赏

import Rewarded from './Rewarded'; //获赏公告

import Header from '../../../../components/common/componentHeader';
import './common.css';
import ScrollWrap from '../../../../components/common/scrollWrap';
import { getUserInfo, getBSGlobal, goReward, getAppCenterApiUrl } from '../../../../helper';
import sizeProvider from '../../../../components/common/sizeProVider';

function RightCom() {
  //https://www.italent.cn/107109868/ITalentHome#
  //widget%2Fitalent%3FiTalentFrame%3D
  //http://www.italent.link/u/201038245/Home#widget%2Fitalent%3FiTalentNavId%3D12294%26iTalentFrameType%3Diframe%26iTalentFrame%3Dhttp%253A%252F%252Fwww.italent.link%252F201038245%252FUIBuilder%253Ftenant_id%2523%252F%26user_id%3D201038245%26app_id%3D100%26time_stamp%3D1528683607%26sign%3D6ecae58ab9172949995174f0e736d86e%26sign_type%3D1%23%2FCompanyContacts
  //https%253A%252F%252Fwww.italent.cn%252F107109868%252FUIBuilder%2523%252FPersonalSettings%26
  var userInfo = getUserInfo();
  var uid = userInfo.Id;
  var bountyUrl = getAppCenterApiUrl("/BountySetting?isvId=".concat(getBSGlobal('isv') || getBSGlobal('ISVType') || '10001'));
  var url = "//".concat(getBSGlobal('isvDomain'), "/").concat(uid, "/ITalentHome#") + encodeURIComponent("widget/italent?iTalentFrame=".concat(encodeURIComponent(bountyUrl)));
  return React.createElement("span", {
    className: 'right-component',
    onClick: function onClick() {
      window.open(url);
    }
  }, "\u67E5\u770B\u6211\u7684\u6253\u8D4F");
}

var RewardedWrap =
/*#__PURE__*/
function (_React$Component) {
  _inherits(RewardedWrap, _React$Component);

  function RewardedWrap() {
    var _this;

    _classCallCheck(this, RewardedWrap);

    _this = _possibleConstructorReturn(this, _getPrototypeOf(RewardedWrap).apply(this, arguments));

    _this.turn = function () {
      _this.props.flipTrigger();
    };

    return _this;
  }

  _createClass(RewardedWrap, [{
    key: "render",
    value: function render() {
      return React.createElement("div", {
        className: 'reward-wrap'
      }, React.createElement(Header, {
        icon: 'font-reward',
        title: "\u83B7\u8D4F\u516C\u544A\u677F",
        color: '#ee484f',
        rightComponent: RightCom,
        outWidth: '50px'
      }), React.createElement("div", {
        className: 'inner-wrap-rewarded'
      }, React.createElement(Rewarded, {
        goReward: goReward
      })), React.createElement("span", {
        className: 'icon-bottom font-flip',
        onClick: this.turn
      }));
    }
  }]);

  return RewardedWrap;
}(React.Component);

var RewardWrap =
/*#__PURE__*/
function (_React$Component2) {
  _inherits(RewardWrap, _React$Component2);

  function RewardWrap() {
    var _this2;

    _classCallCheck(this, RewardWrap);

    _this2 = _possibleConstructorReturn(this, _getPrototypeOf(RewardWrap).apply(this, arguments));

    _this2.turn = function () {
      _this2.props.flipTrigger(_this2.props.visiable);
    };

    return _this2;
  }

  _createClass(RewardWrap, [{
    key: "render",
    value: function render() {
      var _this$props = this.props,
          pHeight = _this$props.pHeight,
          pWidth = _this$props.pWidth;
      return React.createElement("div", {
        className: pWidth < 301 ? 'reward-wrap reward-wrap-little' : 'reward-wrap'
      }, React.createElement(Header, {
        icon: 'font-reward',
        title: "\u6253\u8D4F",
        color: '#ee484f',
        rightComponent: RightCom,
        outWidth: '50px'
      }), React.createElement(ScrollWrap, {
        height: 'calc(100% - 57px)'
      }, React.createElement("div", {
        className: 'inner'
      }, React.createElement("div", {
        className: 'inner-wrap',
        style: {
          minHeight: pHeight - 80 + 'px'
        }
      }, React.createElement(Reward, Object.assign({}, this.props))))), React.createElement("span", {
        className: 'icon-bottom font-flip',
        onClick: this.turn
      }));
    }
  }]);

  return RewardWrap;
}(React.Component);

RewardWrap.displayTitle = '打赏获赏';
RewardWrap.backSide = RewardedWrap;
export default sizeProvider(RewardWrap);

==> ux-reward-wrap-3.0.3.tgz: package/lib/components/pageBuilder/ElementCollection/RewardWrap/index.js <==
import "core-js/modules/es6.object.assign";
import _classCallCheck from "@babel/runtime/helpers/classCallCheck";
import _createClass from "@babel/runtime/helpers/createClass";
import _possibleConstructorReturn from "@babel/runtime/helpers/possibleConstructorReturn";
import _getPrototypeOf from "@babel/runtime/helpers/getPrototypeOf";
import _inherits from "@babel/runtime/helpers/inherits";
import * as React from 'react';
import Reward from './Reward'; //打赏

import Rewarded from './Rewarded'; //获赏公告

import Header from '../../../../components/common/componentHeader';
import './common.css';
import ScrollWrap from '../../../../components/common/scrollWrap';
import { getUserInfo, getBSGlobal, goReward, getAppCenterApiUrl, isTita, bountyManagementLink } from '../../../../helper';
import sizeProvider from '../../../../components/common/sizeProVider';

function RightCom() {
  //https://www.italent.cn/107109868/ITalentHome#
  //widget%2Fitalent%3FiTalentFrame%3D
  //http://www.italent.link/u/201038245/Home#widget%2Fitalent%3FiTalentNavId%3D12294%26iTalentFrameType%3Diframe%26iTalentFrame%3Dhttp%253A%252F%252Fwww.italent.link%252F201038245%252FUIBuilder%253Ftenant_id%2523%252F%26user_id%3D201038245%26app_id%3D100%26time_stamp%3D1528683607%26sign%3D6ecae58ab9172949995174f0e736d86e%26sign_type%3D1%23%2FCompanyContacts
  //https%253A%252F%252Fwww.italent.cn%252F107109868%252FUIBuilder%2523%252FPersonalSettings%26
  var userInfo = getUserInfo();
  var uid = userInfo.Id;
  var bountyUrl = isTita() ? bountyManagementLink : getAppCenterApiUrl("/BountySetting?isvId=".concat(getBSGlobal('isv') || getBSGlobal('ISVType') || '10001'));
  var url = "//".concat(getBSGlobal('isvDomain'), "/").concat(uid, "/ITalentHome#") + encodeURIComponent("widget/italent?iTalentFrame=".concat(encodeURIComponent(bountyUrl)));
  return React.createElement("span", {
    className: 'right-component',
    onClick: function onClick() {
      window.open(url);
    }
  }, "\u67E5\u770B\u6211\u7684\u6253\u8D4F");
}

var RewardedWrap =
/*#__PURE__*/
function (_React$Component) {
  _inherits(RewardedWrap, _React$Component);

  function RewardedWrap() {
    var _this;

    _classCallCheck(this, RewardedWrap);

    _this = _possibleConstructorReturn(this, _getPrototypeOf(RewardedWrap).apply(this, arguments));

    _this.turn = function () {
      _this.props.flipTrigger();
    };

    return _this;
  }

  _createClass(RewardedWrap, [{
    key: "render",
    value: function render() {
      return React.createElement("div", {
        className: 'reward-wrap'
      }, React.createElement(Header, {
        icon: 'font-reward',
        title: "\u83B7\u8D4F\u516C\u544A\u677F",
        color: '#ee484f',
        rightComponent: RightCom,
        outWidth: '50px'
      }), React.createElement("div", {
        className: 'inner-wrap-rewarded'
      }, React.createElement(Rewarded, {
        goReward: goReward
      })), React.createElement("span", {
        className: 'icon-bottom font-flip',
        onClick: this.turn
      }));
    }
  }]);

  return RewardedWrap;
}(React.Component);

var RewardWrap =
/*#__PURE__*/
function (_React$Component2) {
  _inherits(RewardWrap, _React$Component2);

  function RewardWrap() {
    var _this2;

    _classCallCheck(this, RewardWrap);

    _this2 = _possibleConstructorReturn(this, _getPrototypeOf(RewardWrap).apply(this, arguments));

    _this2.turn = function () {
      _this2.props.flipTrigger(_this2.props.visiable);
    };

    return _this2;
  }

  _createClass(RewardWrap, [{
    key: "render",
    value: function render() {
      var _this$props = this.props,
          pHeight = _this$props.pHeight,
          pWidth = _this$props.pWidth;
      return React.createElement("div", {
        className: pWidth < 301 ? 'reward-wrap reward-wrap-little' : 'reward-wrap'
      }, React.createElement(Header, {
        icon: 'font-reward',
        title: "\u6253\u8D4F",
        color: '#ee484f',
        rightComponent: RightCom,
        outWidth: '50px'
      }), React.createElement(ScrollWrap, {
        height: 'calc(100% - 57px)'
      }, React.createElement("div", {
        className: 'inner'
      }, React.createElement("div", {
        className: 'inner-wrap',
        style: {
          minHeight: pHeight - 80 + 'px'
        }
      }, React.createElement(Reward, Object.assign({}, this.props))))), React.createElement("span", {
        className: 'icon-bottom font-flip',
        onClick: this.turn
      }));
    }
  }]);

  return RewardWrap;
}(React.Component);

RewardWrap.displayTitle = '打赏获赏';
RewardWrap.backSide = RewardedWrap;
export default sizeProvider(RewardWrap);
